==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/LowB/PrimIntegerLe.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v160	((void*)startLabel+40)
#define ST_v159	((void*)startLabel+68)
#define PS_v158	((void*)startLabel+92)
void FR_Prelude_46primIntegerLe(void);
extern Node PM_Prelude[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v160)
,};
Node FN_Prelude_46primIntegerLe[] = {
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_Prelude_46primIntegerLe)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 50039
, useLabel(ST_v159)
,	/* CT_v160: (byte 0) */
  HW(0,2)
, 0
,};
Node F0_Prelude_46primIntegerLe[] = {
  CAPTAG(useLabel(FN_Prelude_46primIntegerLe),2)
, useLabel(PS_v158)
, 0
, 0
, 0
,};
Node PP_Prelude_46primIntegerLe[] = {
 };
Node PC_Prelude_46primIntegerLe[] = {
 	/* ST_v159: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(112,114,105,109)
, bytes2word(73,110,116,101)
, bytes2word(103,101,114,76)
, bytes2word(101,0,0,0)
,	/* PS_v158: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46primIntegerLe)
, useLabel(PC_Prelude_46primIntegerLe)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "primIntegerLeC" Prelude.primIntegerLe 2 :: Prelude.Integer -> Prelude.Integer -> Prelude.Bool */
extern HsBool primIntegerLeC(NodePtr,NodePtr);
#ifdef PROFILE
static SInfo pf_primIntegerLeC = {"Prelude","Prelude.primIntegerLe","Prelude.Bool"};
#endif
C_HEADER(FR_Prelude_46primIntegerLe) {
  NodePtr nodeptr;
  HsBool result;
  NodePtr arg1;
  NodePtr arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (NodePtr)nodeptr;
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (NodePtr)nodeptr;

  result = primIntegerLeC(arg1,arg2);

  nodeptr = nhc_mkBool(result);
  INIT_PROFINFO(nodeptr,&pf_primIntegerLeC);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/LowB/PrimIntegerLe.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define CT_v163	((void*)startLabel+40)
#define ST_v162	((void*)startLabel+68)
#define PS_v161	((void*)startLabel+92)
void FR_Prelude_46primIntegerLe(void);
extern Node PM_Prelude[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v163)
,};
Node FN_Prelude_46primIntegerLe[] = {
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_Prelude_46primIntegerLe)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 50001
, useLabel(ST_v162)
,	/* CT_v163: (byte 0) */
  HW(0,2)
, 0
,};
Node F0_Prelude_46primIntegerLe[] = {
  CAPTAG(useLabel(FN_Prelude_46primIntegerLe),2)
, useLabel(PS_v161)
, 0
, 0
, 0
,};
Node PP_Prelude_46primIntegerLe[] = {
 };
Node PC_Prelude_46primIntegerLe[] = {
 	/* ST_v162: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(112,114,105,109)
, bytes2word(73,110,116,101)
, bytes2word(103,101,114,76)
, bytes2word(101,0,0,0)
,	/* PS_v161: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46primIntegerLe)
, useLabel(PC_Prelude_46primIntegerLe)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "primIntegerLeC" Prelude.primIntegerLe 2 :: Prelude.Integer -> Prelude.Integer -> Prelude.Bool */
extern HsBool primIntegerLeC(NodePtr,NodePtr);
#ifdef PROFILE
static SInfo pf_Prelude_46primIntegerLe = {"Prelude","Prelude.primIntegerLe","Prelude.Bool"};
#endif
C_HEADER(FR_Prelude_46primIntegerLe) {
  NodePtr nodeptr;
  HsBool result;
  NodePtr arg1;
  NodePtr arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (NodePtr)nodeptr;
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (NodePtr)nodeptr;

  result = primIntegerLeC(arg1,arg2);

  nodeptr = nhc_mkBool(result);
  INIT_PROFINFO(nodeptr,&pf_Prelude_46primIntegerLe);
  C_RETURN(nodeptr);
}
